@@ -38,6 +38,9 @@ define('port', default=8080, help='Port to listen on')
 define('address', default='127.0.0.1', help='Address to bind on')
 
 
+define('socketfd', default=None, help='Filedescriptor used from circus')
+
+
 class Service(object):
     '''Main service implementation managing the `tornado.web.Application` and
     taking care of configuration.'''
@@ -47,8 +50,15 @@ class Service(object):
         app = self.get_app()
 
         server = HTTPServer(app)
-        server.bind(self.config.port, address=self.config.address)
-        server.start(1)
+
+        if self.config.socketfd:
+            import socket
+            sock = socket.fromfd(int(self.config.socketfd), socket.AF_INET,
+                                 socket.SOCK_STREAM)
+            server.add_socket(sock)
+        else:
+            server.bind(self.config.port, address=self.config.address)
+            server.start(1)
 
         self.slog.info('Starting supercell')
         IOLoop.instance().start()
@@ -96,11 +106,9 @@ class Service(object):
         '''Parse the config files and return the `config` object, i.e. the
         `tornado.options.options` instance.'''
         filename = self.environment.config_name
-        print(self.environment.config_file_paths)
         for path in self.environment.config_file_paths:
             cfg = os.path.join(path, 'config.cfg')
             if os.path.exists(cfg):
-                print(cfg)
                 tornado.options.parse_config_file(cfg)
 
             cfg = os.path.join(path, filename)
@@ -114,7 +122,6 @@ class Service(object):
 
     def initialize_logging(self, name='supercell'):
         '''Initialize the python logging system.'''
-        print(self.config.logconf)
         logging.config.fileConfig(self.config.logconf)
         slog = logging.getLogger(name)
         ts = self.environment.tornado_settings
